@@ -1,5 +1,5 @@
 package Starch::Manager;
-$Starch::Manager::VERSION = '0.02';
+$Starch::Manager::VERSION = '0.03';
 =head1 NAME
 
 Starch::Manager - Entry point for accessing Starch state objects.
@@ -17,11 +17,12 @@ Typically you will be using the L<Starch> module to create this
 object.
 
 This class supports method proxies as described in
-L<Starch/METHOD PROXIES>.
+L<Starch::Manual/METHOD PROXIES>.
 
 =cut
 
 use Starch::State;
+use Starch::Util qw( croak );
 use Storable qw( freeze dclone );
 
 use Types::Standard -types;
@@ -57,7 +58,7 @@ C<class> key and will be converted into a store object automatically.
 The C<class> can be fully qualified, or relative to the C<Starch::Store>
 namespace.  A leading C<::> signifies that the store's package name is relative.
 
-More information about stores can be found at L<Starch/STORES>.
+More information about stores can be found at L<Starch::Manual/STORES>.
 
 =cut
 
@@ -84,6 +85,21 @@ sub _build_store {
     );
 }
 
+=head2 factory
+
+The underlying L<Starch::Factory> object which manages all the plugins
+and state/store object construction.
+
+This argument is automatically set when calling C<new> on L<Starch>.
+
+=cut
+
+has factory => (
+    is       => 'ro',
+    isa      => InstanceOf[ 'Starch::Factory' ],
+    required => 1,
+);
+
 =head1 OPTIONAL ARGUMENTS
 
 =head2 expires
@@ -91,7 +107,7 @@ sub _build_store {
 How long, in seconds, a state should live after the last time it was
 modified.  Defaults to C<60 * 60 * 2> (2 hours).
 
-See L<Starch/EXPIRATION> for more information.
+See L<Starch::Manual/EXPIRATION> for more information.
 
 =cut
 
@@ -110,7 +126,7 @@ that the plugin's package name is relative.
 
 Plugins can modify nearly any functionality in Starch.  More information
 about plugins, as well as which plugins are available, can be found at
-L<Starch/PLUGINS>.
+L<Starch::Manual/PLUGINS>.
 
 =cut
 
@@ -201,22 +217,16 @@ has invalid_state_key => (
     default => '__STARCH_INVALID__',
 );
 
-=head1 REQUIRED ARGUMENTS
+=head1 ATTRIBUTES
 
-=head2 factory
+=head2 state_id_type
 
-The underlying L<Starch::Factory> object which manages all the plugins
-and state/store object construction.
-
-This argument is automatically set when calling C<new> on L<Starch>.
+The L<Type::Tiny> object to validate the state ID when L</state>
+is called.  Defaults to L<NonEmptySimpleStr>.
 
 =cut
 
-has factory => (
-    is       => 'ro',
-    isa      => InstanceOf[ 'Starch::Factory' ],
-    required => 1,
-);
+sub state_id_type { NonEmptySimpleStr }
 
 =head1 METHODS
 
@@ -239,6 +249,9 @@ sub state {
     my $self = shift;
     my $id = shift;
 
+    croak 'Invalid Starch State ID: ' . $self->state_id_type->get_message( $id )
+        if defined($id) and !$self->state_id_type->check( $id );
+
     my $class = $self->factory->state_class();
 
     my $extra_args = $class->BUILDARGS( @_ );
