@@ -1,5 +1,5 @@
 package Starch::Role::Log;
-$Starch::Role::Log::VERSION = '0.02';
+$Starch::Role::Log::VERSION = '0.03';
 =head1 NAME
 
 Starch::Role::Log - Logging capabilities used internally by Starch.
@@ -26,7 +26,7 @@ No logging is produced by the stock L<Starch>.  The
 L<Starch::Plugin::Trace> plugin adds extensive logging.
 
 More info about logging can be found at
-L<Starch/LOGGING>.
+L<Starch::Manual/LOGGING>.
 
 =cut
 
