@@ -1,5 +1,5 @@
 package Starch::State;
-$Starch::State::VERSION = '0.02';
+$Starch::State::VERSION = '0.03';
 =head1 NAME
 
 Starch::State - The Starch state object.
@@ -22,7 +22,7 @@ use Scalar::Util qw( refaddr );
 use Types::Standard -types;
 use Types::Common::String -types;
 use Digest::SHA qw( sha1_hex );
-use Carp qw( croak );
+use Starch::Util qw( croak );
 
 use Moo;
 use strictures 2;
@@ -59,7 +59,6 @@ the state will be considered new.
 
 has _existing_id => (
     is        => 'ro',
-    isa       => NonEmptySimpleStr,
     init_arg  => 'id',
     predicate => 1,
     clearer   => '_clear_existing_id',
