@@ -1,12 +1,12 @@
 package Starch::Util;
-$Starch::Util::VERSION = '0.02';
+$Starch::Util::VERSION = '0.03';
 =head1 NAME
 
 Starch::Util - Utility functions used internally by Starch.
 
 =cut
 
-use Carp qw( croak );
+use Carp qw();
 use Module::Runtime qw( require_module is_module_name );
 
 use strictures 2;
@@ -17,6 +17,47 @@ our @EXPORT_OK;
 
 =head1 FUNCTIONS
 
+=head2 croak
+
+This is a custom L<Carp> C<croak> function which sets various
+standard starch packages as C<Internal> so that Carp looks
+deeper in the stack for something to blame which makes exceptions
+be more contextually useful for users of Starch and means we don't
+need to use confess which generates giant stack traces.
+
+=cut
+
+push @EXPORT_OK, 'croak';
+sub croak {
+    local $Carp::Internal{'Starch::Factory'} = 1;
+    local $Carp::Internal{'Starch::Manager'} = 1;
+    local $Carp::Internal{'Starch::Plugin::AlwaysLoad'} = 1;
+    local $Carp::Internal{'Starch::Plugin::Bundle'} = 1;
+    local $Carp::Internal{'Starch::Plugin::CookieArgs::Manager'} = 1;
+    local $Carp::Internal{'Starch::Plugin::CookieArgs::State'} = 1;
+    local $Carp::Internal{'Starch::Plugin::DisableStore'} = 1;
+    local $Carp::Internal{'Starch::Plugin::ForManager'} = 1;
+    local $Carp::Internal{'Starch::Plugin::ForState'} = 1;
+    local $Carp::Internal{'Starch::Plugin::ForStore'} = 1;
+    local $Carp::Internal{'Starch::Plugin::LogStoreExceptions'} = 1;
+    local $Carp::Internal{'Starch::Plugin::RenewExpiration::Manager'} = 1;
+    local $Carp::Internal{'Starch::Plugin::RenewExpiration::State'} = 1;
+    local $Carp::Internal{'Starch::Plugin::ThrottleStore'} = 1;
+    local $Carp::Internal{'Starch::Plugin::TimeoutStore'} = 1;
+    local $Carp::Internal{'Starch::Plugin::Trace::Manager'} = 1;
+    local $Carp::Internal{'Starch::Plugin::Trace::State'} = 1;
+    local $Carp::Internal{'Starch::Plugin::Trace::Store'} = 1;
+    local $Carp::Internal{'Starch::Role::Log'} = 1;
+    local $Carp::Internal{'Starch::Role::MethodProxy'} = 1;
+    local $Carp::Internal{'Starch::State'} = 1;
+    local $Carp::Internal{'Starch::Store::Layered'} = 1;
+    local $Carp::Internal{'Starch::Store::Memory'} = 1;
+    local $Carp::Internal{'Starch::Store'} = 1;
+    local $Carp::Internal{'Starch::Util'} = 1;
+
+    return Carp::croak( @_ );
+}
+
 =head2 load_prefixed_module
 
     # These both return "Foo::Bar".
@@ -94,7 +135,7 @@ Is the same as:
     my @ret = Some::Package->some_method( @args );
 
 Method proxies are defined in more detail at
-L<Starch/METHOD PROXIES>.
+L<Starch::Manual/METHOD PROXIES>.
 
 =cut
 
